==> tutti-ui-swing-3.4-sources.jar: fr/ifremer/tutti/ui/swing/action/GoToPreviousScreenAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: GoToPreviousScreenAction.java 1566 2014-02-04 08:31:02Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.4/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/GoToPreviousScreenAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.content.MainUIHandler;

import static org.nuiton.i18n.I18n.t;

/**
 * To return on previous screen.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.1
 */
public class GoToPreviousScreenAction extends AbstractChangeScreenAction {

    public GoToPreviousScreenAction(MainUIHandler handler) {
        super(handler,
              true,
              PREVIOUS_SCREEN.getContextValue(handler.getUI())
        );
        setActionDescription(t("tutti.main.action.goto.previousScreen.tip"));
    }
}

==> tutti-ui-swing-3.4.1-sources.jar: fr/ifremer/tutti/ui/swing/action/GoToPreviousScreenAction.java <==
package fr.ifremer.tutti.ui.swing.action;

/*
 * #%L
 * Tutti :: UI
 * $Id: GoToPreviousScreenAction.java 1566 2014-02-04 08:31:02Z tchemit $
 * $HeadURL: https://svn.codelutin.com/tutti/tags/tutti-3.4.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/action/GoToPreviousScreenAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.ui.swing.content.MainUIHandler;

import static org.nuiton.i18n.I18n.t;

/**
 * To return on previous screen.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 1.1
 */
public class GoToPreviousScreenAction extends AbstractChangeScreenAction {

    public GoToPreviousScreenAction(MainUIHandler handler) {
        super(handler,
              true,
              PREVIOUS_SCREEN.getContextValue(handler.getUI())
        );
        setActionDescription(t("tutti.main.action.goto.previousScreen.tip"));
    }
}
